@@ -131,7 +131,7 @@ sub is_decoder_installed
     return( $@ ? 0 : 1 );
 }
 
-sub is_emcoder_installed
+sub is_encoder_installed
 {
     eval( 'use IO::Compress::Brotli ();' );
     return( $@ ? 0 : 1 );
@@ -254,6 +254,14 @@ It returns true upon success, and upon error, it will set the error in the globa
     die( "Something went wrong: $HTTP::Promise::Stream::Brotli::BrotliError\n" if( !defined( $encoded ) );
     print( "Encoded data is: $encoded\n" );
 
+=head2 is_decoder_installed
+
+Returns true if the module L<IO::Uncompress::Brotli> is installed, false otherwise.
+
+=head2 is_encoder_installed
+
+Returns true if the module L<IO::Compress::Brotli> is installed, false otherwise.
+
 =head1 AUTHOR
 
 Jacques Deguest E<lt>F<jack@deguest.jp>E<gt>
